%* lsaf_createsharedfolder                                                                 *;
%*                                                                                         *;
%* Creates a shared folder in a context in the repository.                                 *;
%*                                                                                         *;
%* macrotype LSAF                                                                          *;
%* since 2.7                                                                               *;
%* exposure external                                                                       *;
%*                                                                                         *;
%* History                                                                                 *;
%* 2024-08-09  initial code                                                                *;
%*                                                                                         *;

%macro lsaf_createsharedfolder(
  lsaf_path=
  ) /des='Create a shared folder in the repository.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
	  _lsafCreateSharedFolderId_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8
           message         length=$200
           logMsgPrefix    length=$70
           logMsg          length=$300
           logMsgPrimary   length=$70
	   sharedFolderId  length=$70
    ; 

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj cmd("com/sas/lsaf/macro/content/repository/RepositoryService");
    declare javaobj results("com/sas/lsaf/macro/common/result/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    cmd.callStaticStringMethod("createSharedFolder", "%bquote(&lsaf_path.)", results, sharedFolderId);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    logMsgPrimary=logMsgPrefix;
    logMsg=" The shared folder was created: &lsaf_path." ;
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" The shared folder was not created: &lsaf_path" ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
	put logMsgPrefix " _lsafCreateSharedFolderId_= " sharedFolderId ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);
	call symputx("_lsafCreateSharedFolderId_", sharedFolderId);

  run;

%mend lsaf_createsharedfolder ;
